@@ -3,6 +3,7 @@ library(nlme)
 skip_if_not_installed("scdhlm")
 
 data(Bryant2018, package = "scdhlm")
+Bryant2018 <- droplevels(subset(Bryant2018, !is.na(outcome)))
 
 #------------------------------------------------------------------------------
 # varying intercept at level 3, ALLOW intercept & trend covariance at level 2
@@ -41,9 +42,10 @@ test_that("mod1_1 and mod1_2 returns the same results.", {
 mod2_1 <- suppressWarnings(lme(fixed = outcome ~ session_c + treatment + session_trt,
               random = list( ~ 1 | school, ~ 1 | case, ~ 0 + session_c | case),
               correlation = corAR1(0, ~ session_c | school/case),
-              data = Bryant2018))
+              data = Bryant2018,
+              control = lmeControl(tolerance = 1e-6)))
 # warning: cannot use smaller level of grouping for 'correlation' than for 'random'. Replacing the former with the latter.
-#VarCorr(mod2_1) # pdLogChol(1) parametrization
+VarCorr(mod2_1) # pdLogChol(1) parametrization
 
 # Fisher_info(mod2_1)
 # g_mod2_1 <- g_mlm(mod2_1, p_const = c(0,0,1,17), r_const = c(1,0,1,0,1))
@@ -53,21 +55,22 @@ mod2_1 <- suppressWarnings(lme(fixed = outcome ~ session_c + treatment + session
 mod2_2 <- lme(fixed = outcome ~ session_c + treatment + session_trt,
               random = list(school = ~ 1, case = pdDiag(~ session_c)),
               correlation = corAR1(0, ~ session_c | school/case),
-              data = Bryant2018)
-#VarCorr(mod2_2) # pdDiag(1) parametrization?
+              data = Bryant2018,
+              control = lmeControl(tolerance = 1e-6))
+VarCorr(mod2_2) # pdDiag(1) parametrization?
 
 Fisher_info(mod2_2)
 g_mod2_2 <- g_mlm(mod2_2, p_const = c(0,0,1,17), r_const = c(1,1,0,0,1))
 #summary(g_mod2_2)
 
 test_that("mod2_1 and mod2_2 return the same results.", {
-  expect_equal(mod2_1$coefficients$fixed, mod2_2$coefficients$fixed)
-  expect_equal(as.numeric(VarCorr(mod2_1)[,2][2]), as.numeric(VarCorr(mod2_2)[,2][2]), tol = 1e-4)
+  expect_equal(mod2_1$coefficients$fixed, mod2_2$coefficients$fixed, tol = 1e-5)
+  expect_equal(as.numeric(VarCorr(mod2_1)[,1][2]), as.numeric(VarCorr(mod2_2)[,1][2]), tol = 1e-3)
   expect_equal(as.numeric(VarCorr(mod2_1)[,2][4]), as.numeric(VarCorr(mod2_2)[,2][4]), tol = 1e-7)
   expect_equal(as.numeric(VarCorr(mod2_1)[,2][6]), as.numeric(VarCorr(mod2_2)[,2][5]), tol = 1e-7)
   expect_equal(as.numeric(VarCorr(mod2_1)[,2][7]), as.numeric(VarCorr(mod2_2)[,2][6]))
   expect_equal(mod2_1$sigma, mod2_2$sigma)
-  expect_equal(mod2_1$varFix, mod2_2$varFix, tolerance = 1e-7) # intercept var differs at 6th decimals
+  expect_equal(mod2_1$varFix, mod2_2$varFix, tolerance = 5e-4) # intercept var differs at 6th decimals
   expect_equal(mod2_1$logLik, mod2_2$logLik)
 })
 
@@ -106,8 +109,8 @@ test_that("Info matrices work with dropped observations.", {
 
   skip_on_cran()
 
-  test_after_deleting(mod1_1)
-  test_after_deleting(mod1_2)
-  test_after_deleting(mod2_2)
+  test_after_deleting(mod1_1, seed = 20230212)
+  test_after_deleting(mod1_2, seed = 20230213)
+  test_after_deleting(mod2_2, seed = 20230214)
 
 })
